@@ -44,6 +44,7 @@ from awscli.customizations.ec2protocolarg import register_protocol_args
 from awscli.customizations import datapipeline
 from awscli.customizations.globalargs import register_parse_global_args
 from awscli.customizations.cloudsearch import initialize as cloudsearch_init
+from awscli.customizations.emr.emr import emr_initialize
 
 
 def awscli_initialize(event_handlers):
@@ -90,3 +91,4 @@ def awscli_initialize(event_handlers):
     register_protocol_args(event_handlers)
     datapipeline.register_customizations(event_handlers)
     cloudsearch_init(event_handlers)
+    emr_initialize(event_handlers)
